==> doc_curation-0.0.2-py3-none-any.whl: curation_projects/misc/wikisource.py <==
from doc_curation import wikisource

if __name__ == '__main__':
    # logging.debug(get_item("http://sanskritabhyas.in/hi/Kridanta/View/%E0%A4%AD%E0%A5%82"))
    # wikisource.dump_text(url_base="अग्निपुराणम्/अध्यायः", num_parts=383, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/agni-purANam/")
    # wikisource.dump_text(url_base="गरुडपुराणम्/आचारकाण्डः/अध्यायः", num_parts=240, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/garuDa-purANam/AchAra-kANDaH/")
    # wikisource.dump_text(url_base="गरुडपुराणम्/प्रेतकाण्डः_(धर्मकाण्डः)/अध्यायः", num_parts=49, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/garuDa-purANam/dharma-kANDaH/")
    # wikisource.dump_text(url_base="गरुडपुराणम्/ब्रह्मकाण्डः_(मोक्षकाण्डः)/अध्यायः", num_parts=29, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/garuDa-purANam/moxa-kANDaH/")
    # wikisource.dump_text(url_base="नारदपुराणम्-_पूर्वार्धः/अध्यायः", num_parts=125, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/nArada-purANam/01/")
    # wikisource.dump_text(url_base="नारदपुराणम्-_उत्तरार्धः/अध्यायः", num_parts=82, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/nArada-purANam/02/")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_१_(सृष्टिखण्डम्)/अध्यायः", num_parts=82, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/01/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_२_(भूमिखण्डः)/अध्यायः", num_parts=125, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/02/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_३_(स्वर्गखण्डः)/अध्यायः", num_parts=62, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/03/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_४_(ब्रह्मखण्डः)/अध्यायः", num_parts=26, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/04/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_५_(पातालखण्डः)/अध्यायः", num_parts=117, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/05/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_६_(उत्तरखण्डः)/अध्यायः", num_parts=255, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/06/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_७_(क्रियाखण्डः)/अध्यायः", num_parts=26, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/07/", url_id_padding="%02d")

    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_१_(ब्रह्मखण्डः)/अध्यायः", num_parts=30, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/01/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_२_(प्रकृतिखण्डः)/अध्यायः", num_parts=67, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/02/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_३_(गणपतिखण्डः)/अध्यायः", num_parts=46, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/03/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_४_(श्रीकृष्णजन्मखण्डः)/अध्यायः", num_parts=133, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/04/", url_id_padding="%03d")

    # wikisource.dump_text(url_base="ब्रह्माण्डपुराणम्/पूर्वभागः/अध्यायः", num_parts=38, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmANDa-purANam/01/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्माण्डपुराणम्/मध्यभागः/अध्यायः", num_parts=74, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmANDa-purANam/02/", url_id_padding="%d")
    # wikisource.dump_text(url_base="ब्रह्माण्डपुराणम्/उत्तरभागः/अध्यायः", num_parts=44, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmANDa-purANam/03/", url_id_padding="%d")
    # wikisource.dump_text(url_base="मत्स्यपुराणम्/अध्यायः", num_parts=291, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/matsya-purANam/", url_id_padding="%d")
    # wikisource.dump_text(url_base="लिङ्गपुराणम्_-_पूर्वभागः/अध्यायः", num_parts=108, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/linga-purANam/01/", url_id_padding="%d")
    # wikisource.dump_text(url_base="लिङ्गपुराणम्_-_उत्तरभागः/अध्यायः", num_parts=55, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/linga-purANam/02/", url_id_padding="%d")
    # wikisource.dump_text(url_base="वायुपुराणम्/पूर्वार्धम्/अध्यायः", num_parts=61, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/vAyu-purANam/01/", url_id_padding="%d")
    # wikisource.dump_text(url_base="वायुपुराणम्/उत्तरार्धम्/अध्यायः", num_parts=50, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/vAyu-purANam/02/", url_id_padding="%d")
    # wikisource.dump_text(url_base="वराहपुराणम्/अध्यायः", num_parts=218, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/varAha-purANam/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="कालिकापुराणम्/अध्यायः", num_parts=90, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/kAlikA-purANam/", url_id_padding="%d")
    # wikisource.dump_text(url_base="श्रीमद्भागवतपुराणम्/स्कन्धः_१०/पूर्वार्धः/अध्यायः", num_parts=90, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/bhAgavata-purANam/10/", url_id_padding="%d")
    # wikisource.dump_text(url_base="श्रीमद्भागवतपुराणम्/स्कन्धः_१०/उत्तरार्धः/अध्यायः", num_parts=90, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/bhAgavata-purANam/10/", url_id_padding="%d")

    # wikisource.dump_deep_text(url_text_id="श्रीमद्भागवतपुराणम्", url_leaf_id_padding="%d", dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/bhAgavata-purANam/", unit_info_file="/home/vvasuki/sanskrit-coders/doc_curation/doc_curation/text_data/puraana/bhaagavatam.json", dry_run=False)


    # wikisource.dump_text(url_base="पैप्पलादसंहिता/काण्डम्", num_parts=20, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/paippalAda/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="अथर्ववेदः/काण्डं", num_parts=20, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/shaunaka/visvara/")

    # wikisource.dump_text(url_base="ऋग्वेदः_खिलसूक्तानि/अध्यायः", num_parts=5, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/shakala/saMhitA/khilAni/visvara/", url_id_padding="%d")
    # wikisource.dump_text(url_base="शुक्लयजुर्वेदः/अध्यायः", num_parts=40, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/mAdhyandina/visvara/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="वेतालपञ्चविंशति", num_parts=25, dir_path="/home/vvasuki/sanskrit/raw_etexts/kAvyam/vetAla-panchavimshatikA/", url_id_padding="%02d", transliterate_id=False)
    wikisource.dump_deep_text(url_text_id="कथासरित्सागरः", url_leaf_id_padding="%d", dir_path="/home/vvasuki/sanskrit/raw_etexts/kAvyam/kathAsaritsAgaraH/", unit_info_file="/home/vvasuki/sanskrit-coders/doc_curation/doc_curation/text_data/kAvyam/kathAsaritsAgaraH.json", dry_run=False)

==> doc_curation-0.1.2-py3-none-any.whl: curation_projects/misc/wikisource.py <==
from doc_curation.scraping import wikisource
from doc_curation.scraping.wikisource import serial


if __name__ == '__main__':
    # logging.debug(get_item("http://sanskritabhyas.in/hi/Kridanta/View/%E0%A4%AD%E0%A5%82"))
    # serial.dump_text(start_url="https://sa.wikisource.org/s/1wlz", out_path="/home/vvasuki/sanskrit/raw_etexts/kalpaH/saMskAraratnamAlA/01/", dry_run=False)
    serial.dump_text(start_url="https://sa.wikisource.org/s/1y6k", out_path="/home/vvasuki/sanskrit/raw_etexts/kalpaH/saMskAraratnamAlA/02/", dry_run=False)
    # wikisource.dump_text(url_base="अग्निपुराणम्/अध्यायः", num_parts=383, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/agni-purANam/")
    # wikisource.dump_text(url_base="गरुडपुराणम्/आचारकाण्डः/अध्यायः", num_parts=240, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/garuDa-purANam/AchAra-kANDaH/")
    # wikisource.dump_text(url_base="गरुडपुराणम्/प्रेतकाण्डः_(धर्मकाण्डः)/अध्यायः", num_parts=49, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/garuDa-purANam/dharma-kANDaH/")
    # wikisource.dump_text(url_base="गरुडपुराणम्/ब्रह्मकाण्डः_(मोक्षकाण्डः)/अध्यायः", num_parts=29, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/garuDa-purANam/moxa-kANDaH/")
    # wikisource.dump_text(url_base="नारदपुराणम्-_पूर्वार्धः/अध्यायः", num_parts=125, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/nArada-purANam/01/")
    # wikisource.dump_text(url_base="नारदपुराणम्-_उत्तरार्धः/अध्यायः", num_parts=82, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/nArada-purANam/02/")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_१_(सृष्टिखण्डम्)/अध्यायः", num_parts=82, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/01/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_२_(भूमिखण्डः)/अध्यायः", num_parts=125, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/02/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_३_(स्वर्गखण्डः)/अध्यायः", num_parts=62, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/03/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_४_(ब्रह्मखण्डः)/अध्यायः", num_parts=26, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/04/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_५_(पातालखण्डः)/अध्यायः", num_parts=117, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/05/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_६_(उत्तरखण्डः)/अध्यायः", num_parts=255, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/06/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="पद्मपुराणम्/खण्डः_७_(क्रियाखण्डः)/अध्यायः", num_parts=26, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/padma-purANam/07/", url_id_padding="%02d")

    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_१_(ब्रह्मखण्डः)/अध्यायः", num_parts=30, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/01/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_२_(प्रकृतिखण्डः)/अध्यायः", num_parts=67, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/02/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_३_(गणपतिखण्डः)/अध्यायः", num_parts=46, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/03/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्मवैवर्तपुराणम्/खण्डः_४_(श्रीकृष्णजन्मखण्डः)/अध्यायः", num_parts=133, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmavaivarta-purANam/04/", url_id_padding="%03d")

    # wikisource.dump_text(url_base="ब्रह्माण्डपुराणम्/पूर्वभागः/अध्यायः", num_parts=38, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmANDa-purANam/01/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="ब्रह्माण्डपुराणम्/मध्यभागः/अध्यायः", num_parts=74, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmANDa-purANam/02/", url_id_padding="%d")
    # wikisource.dump_text(url_base="ब्रह्माण्डपुराणम्/उत्तरभागः/अध्यायः", num_parts=44, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/brahmANDa-purANam/03/", url_id_padding="%d")
    # wikisource.dump_text(url_base="मत्स्यपुराणम्/अध्यायः", num_parts=291, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/matsya-purANam/", url_id_padding="%d")
    # wikisource.dump_text(url_base="लिङ्गपुराणम्_-_पूर्वभागः/अध्यायः", num_parts=108, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/linga-purANam/01/", url_id_padding="%d")
    # wikisource.dump_text(url_base="लिङ्गपुराणम्_-_उत्तरभागः/अध्यायः", num_parts=55, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/linga-purANam/02/", url_id_padding="%d")
    # wikisource.dump_text(url_base="वायुपुराणम्/पूर्वार्धम्/अध्यायः", num_parts=61, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/vAyu-purANam/01/", url_id_padding="%d")
    # wikisource.dump_text(url_base="वायुपुराणम्/उत्तरार्धम्/अध्यायः", num_parts=50, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/vAyu-purANam/02/", url_id_padding="%d")
    # wikisource.dump_text(url_base="वराहपुराणम्/अध्यायः", num_parts=218, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/varAha-purANam/", url_id_padding="%03d")
    # wikisource.dump_text(url_base="कालिकापुराणम्/अध्यायः", num_parts=90, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/kAlikA-purANam/", url_id_padding="%d")
    # wikisource.dump_text(url_base="श्रीमद्भागवतपुराणम्/स्कन्धः_१०/पूर्वार्धः/अध्यायः", num_parts=90, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/bhAgavata-purANam/10/", url_id_padding="%d")
    # wikisource.dump_text(url_base="श्रीमद्भागवतपुराणम्/स्कन्धः_१०/उत्तरार्धः/अध्यायः", num_parts=90, dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/bhAgavata-purANam/10/", url_id_padding="%d")

    # wikisource.dump_deep_text(url_text_id="श्रीमद्भागवतपुराणम्", url_leaf_id_padding="%d", dir_path="/home/vvasuki/sanskrit/raw_etexts/purANa/bhAgavata-purANam/", unit_info_file="/home/vvasuki/sanskrit-coders/doc_curation/doc_curation/text_data/puraana/bhaagavatam.json", dry_run=False)


    # wikisource.dump_text(url_base="पैप्पलादसंहिता/काण्डम्", num_parts=20, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/paippalAda/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="अथर्ववेदः/काण्डं", num_parts=20, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/shaunaka/visvara/")

    # wikisource.dump_text(url_base="ऋग्वेदः_खिलसूक्तानि/अध्यायः", num_parts=5, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/shakala/saMhitA/khilAni/visvara/", url_id_padding="%d")
    # wikisource.dump_text(url_base="शुक्लयजुर्वेदः/अध्यायः", num_parts=40, dir_path="/home/vvasuki/sanskrit/raw_etexts/veda/mAdhyandina/visvara/", url_id_padding="%02d")
    # wikisource.dump_text(url_base="वेतालपञ्चविंशति", num_parts=25, dir_path="/home/vvasuki/sanskrit/raw_etexts/kAvyam/vetAla-panchavimshatikA/", url_id_padding="%02d", transliterate_id=False)
    # wikisource.dump_deep_text(url_text_id="कथासरित्सागरः", url_leaf_id_padding="%d", dir_path="/home/vvasuki/sanskrit/raw_etexts/kAvyam/kathAsaritsAgaraH/", unit_info_file="/home/vvasuki/sanskrit-coders/doc_curation/doc_curation/text_data/kAvyam/kathAsaritsAgaraH.json", dry_run=False)
